/*
 *
 *	Copyright (C) Performance Awareness Corporation, 1986, 1987, 1988,
 *		1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996
 *	ALL RIGHTS RESERVED WORLDWIDE.
 *
 *	This Module contains Proprietary Information of
 *	Performance Awareness Corporation
 *	and should be treated as Confidential.
 *
 *	preVue is a trademark of Performance Awareness Corporation.
 *
 */

/*
 *
 * preVue-C/S header file
 *
 */

#ifndef __preVueCS_h__
#define __preVueCS_h__

/*
 * ALL_ROWS is used in sqlnrecv commands to request all available
 * results
 */
#define ALL_ROWS	0


/*
 * the following errors may be returned by some sql emulation commands
 * or functions.  They are not generated by the sql database server but
 * by preVue-C/S.  All other errors returned by sql emulation commands
 * and functions are provided by the sql database server.
 */
#define PV_SQL_BASE		40000
#define PV_SQL_INTERNAL		(PV_SQL_BASE+ 0)  /* internal library error */
#define PV_SQL_LIBINIT		(PV_SQL_BASE+ 1)  /* lib initializaion */
#define PV_SQL_CONNECT		(PV_SQL_BASE+ 2)  /* failure to connect */
#define PV_SQL_TIMEOUT		(PV_SQL_BASE+ 3)  /* took too long */

#define PV_SQL_END_DATA		(PV_SQL_BASE+ 11) /* end of result set */
#define PV_SQL_END_RESULTS	(PV_SQL_BASE+ 12) /* end of all results */
#define PV_SQL_NOT_FETCHABLE	(PV_SQL_BASE+ 13) /* no results */

#define PV_SQL_UNIMPLEMENTED	(PV_SQL_BASE+ 21) /* unimplemented feature */
#define PV_SQL_MISMATCH		(PV_SQL_BASE+ 22) /* type mismatch */
#define PV_SQL_INVALID		(PV_SQL_BASE+ 23) /* invalid value */

#define PV_SQL_PREPID		(PV_SQL_BASE+ 31) /* unknown stmt id */
#define PV_SQL_PREPCON		(PV_SQL_BASE+ 32) /* other con's stmt id */
#define PV_SQL_PREPFAIL		(PV_SQL_BASE+ 33) /* failed prepare stmt id */

#define PV_SQL_CURSORID		(PV_SQL_BASE+ 41) /* unknown cursor id */
#define PV_SQL_CURSORCON	(PV_SQL_BASE+ 42) /* other con's cursor id */
#define PV_SQL_CURSORFAIL	(PV_SQL_BASE+ 43) /* failed declare cursor id */
#define PV_SQL_MULTIPLE_ERROR   (PV_SQL_BASE+ 44) /* multiple errors */




/*
 * sqlsetoption(option, optarg, ...) option types listed by vendor
 */

/*
 * oracle options
 */
#define ORA_OPT_BASE		6000
#define ORA_AUTOCOMMIT		(ORA_OPT_BASE+ 1)  /* 1 boolean argument */


/*
 * sybase options
 *
 * these options correspond to their obvious counterparts listed in the
 * Sybase include file 'cspublic.h'
 */
#define SYB_OPT_BASE		5000
#define SYB_OPT_DATEFIRST	(SYB_OPT_BASE+ 1) /* Set first day of week */
#define SYB_OPT_TEXTSIZE	(SYB_OPT_BASE+ 2) /* Text size */
#define SYB_OPT_STATS_TIME	(SYB_OPT_BASE+ 3) /* Server time statistics */
#define SYB_OPT_STATS_IO	(SYB_OPT_BASE+ 4) /* Server I/O statistics */
#define SYB_OPT_ROWCOUNT	(SYB_OPT_BASE+ 5) /* Maximum row count */
#define SYB_OPT_NATLANG		(SYB_OPT_BASE+ 6) /* National Language */
#define SYB_OPT_DATEFORMAT	(SYB_OPT_BASE+ 7) /* Date format */
#define SYB_OPT_ISOLATION	(SYB_OPT_BASE+ 8) /* Transaction isolation
						   * level */
#define SYB_OPT_AUTHON		(SYB_OPT_BASE+ 9) /* Set authority level on */
#define SYB_OPT_CHARSET		(SYB_OPT_BASE+10) /* Character set */
#define SYB_OPT_SHOWPLAN	(SYB_OPT_BASE+13) /* show execution plan */
 
#define SYB_OPT_NOEXEC		(SYB_OPT_BASE+14) /* don't execute query */
#define SYB_OPT_ARITHIGNORE	(SYB_OPT_BASE+15) /* ignore arithmetic
						   * exceptions */
#define SYB_OPT_TRUNCIGNORE	(SYB_OPT_BASE+16) /* support ANSI null values */
#define SYB_OPT_ARITHABORT	(SYB_OPT_BASE+17) /* abort on arithmetic
						   * exceptions */
#define SYB_OPT_PARSEONLY	(SYB_OPT_BASE+18) /* parse only, return error
						   * msgs */
#define SYB_OPT_GETDATA		(SYB_OPT_BASE+20) /* return trigger data */
#define SYB_OPT_NOCOUNT		(SYB_OPT_BASE+21) /* don't print done count */
#define SYB_OPT_FORCEPLAN	(SYB_OPT_BASE+23) /* force variable substitute
						   * order */
#define SYB_OPT_FORMATONLY	(SYB_OPT_BASE+24) /* send format w/o row */
#define SYB_OPT_CHAINXACTS	(SYB_OPT_BASE+25) /* chained transaction mode */
#define SYB_OPT_CURCLOSEONXACT	(SYB_OPT_BASE+26) /* close cursor on end trans*/
#define SYB_OPT_FIPSFLAG	(SYB_OPT_BASE+27) /* FIPS flag */
#define SYB_OPT_RESTREES	(SYB_OPT_BASE+28) /* return resolution trees */
#define SYB_OPT_IDENTITYON	(SYB_OPT_BASE+29) /* turn on explicit identity*/
#define SYB_OPT_CURREAD		(SYB_OPT_BASE+30) /* Set session label
						   * @@ curread */
#define SYB_OPT_CURWRITE	(SYB_OPT_BASE+31) /* Set session label 
						   * @@curwrite */
#define SYB_OPT_IDENTITYOFF	(SYB_OPT_BASE+32) /*turn off explicit identity*/
#define SYB_OPT_AUTHOFF		(SYB_OPT_BASE+33) /* Set authority level off */
#define SYB_OPT_ANSINULL	(SYB_OPT_BASE+34) /* ANSI NULLS behavior */
#define SYB_OPT_QUOTED_IDENT	(SYB_OPT_BASE+35) /* Quoted identifiers */
#define SYB_OPT_ANSIPERM	(SYB_OPT_BASE+36) /* ANSI permission checking */
#define SYB_OPT_STR_RTRUNC	(SYB_OPT_BASE+37) /* ANSI right truncation */
 
#define SYB_MIN_OPTION	SYB_OPT_DATEFIRST
#define SYB_MAX_OPTION	SYB_OPT_STR_RTRUNC

/*
 * The types and values for optarg are listed below for Sybase
 * options.  All Sybase options require exactly one optarg.
 * 
 * option			arg type	optarg
 * ---------------		---------	---------
 * SYB_OPT_DATEFIRST 		int		Defines below
 * SYB_OPT_TEXTSIZE 		int		Size in bytes 
 * SYB_OPT_ROWCOUNT  		int		Number of rows 
 * SYB_OPT_NATLANG 		string		National Lang
 * SYB_OPT_DATEFORMAT 		int		Defines below
 * SYB_OPT_ISOLATION 		int		Defines below		
 * SYB_OPT_AUTHON 		string		Table Name
 * SYB_OPT_CHARSET 		string		Character set
 * SYB_OPT_IDENTITYON 		string		Table Name
 * SYB_OPT_CURREAD 		string		Read Label
 * SYB_OPT_CURWRITE 		string		Write Label
 * SYB_OPT_IDENTITYOFF 		string		Table Name
 * SYB_OPT_AUTHOFF 		string		Table Name
 * (All remaining options)	int		Boolean value (non-zero true)
 */ 


/* SYB_OPT_DATEFIRST */
#define SYB_OPT_MONDAY		1
#define SYB_OPT_TUESDAY		2
#define SYB_OPT_WEDNESDAY	3
#define SYB_OPT_THURSDAY	4
#define SYB_OPT_FRIDAY		5
#define SYB_OPT_SATURDAY	6
#define SYB_OPT_SUNDAY		7

/* SYB_OPT_DATEFORMAT */
#define SYB_OPT_FMTMDY		1
#define SYB_OPT_FMTDMY		2
#define SYB_OPT_FMTYMD		3
#define SYB_OPT_FMTYDM		4
#define SYB_OPT_FMTMYD		5
#define SYB_OPT_FMTDYM		6

/* SYB_OPT_ISOLATION */
#define SYB_OPT_LEVEL1		1
#define SYB_OPT_LEVEL3		3

/* DB-Library options taken from sybdb.h */
#define DB_OPT_PARSEONLY     0
#define DB_OPT_ESTIMATE      1       
#define DB_OPT_SHOWPLAN      2
#define DB_OPT_NOEXEC        3
#define DB_OPT_ARITHIGNORE   4
#define DB_OPT_NOCOUNT       5
#define DB_OPT_ARITHABORT    6
#define DB_OPT_TEXTLIMIT     7
#define DB_OPT_BROWSE        8
#define DB_OPT_OFFSET        9
#define DB_OPT_STAT          10
#define DB_OPT_ERRLVL        11
#define DB_OPT_CONFIRM       12
#define DB_OPT_STORPROCID    13
#define DB_OPT_BUFFER        14
#define DB_OPT_NOAUTOFREE    15
#define DB_OPT_ROWCOUNT      16
#define DB_OPT_TEXTSIZE      17
#define DB_OPT_NATLANG       18
#define DB_OPT_DATEFORMAT    19
#define DB_OPT_PRPAD         20
#define DB_OPT_PRCOLSEP      21
#define DB_OPT_PRLINELEN     22
#define DB_OPT_PRLINESEP     23
#define DB_OPT_LFCONVERT     24
#define DB_OPT_DATEFIRST     25
#define DB_OPT_CHAINXACTS    26
#define DB_OPT_FIPSFLAG	     27
#define DB_OPT_ISOLATION     28
#define DB_OPT_AUTH	     29
#define DB_OPT_IDENTITY	     30
#define DB_OPT_NOIDCOL       31


#endif /* __preVueCS_h__ */

