/* 

IBM Confidential 
	
(c) Copyright IBM Corp. 1986, 2005  All Rights Reserved.

The source code for this program is not published or otherwise 
divested of its trade secrets, irrespective of what has been 
deposited with the U.S. Copyright Office.

*/

#ifndef __VU_H__
#define __VU_H__

/*
 *
 * VU header file
 *
 */

/* return values of various VU built-in functions */ 
#ifndef EOF
#define	EOF	-1
#endif
#ifndef NULL
#define	NULL	0
#endif

/* File descriptors to be used for formatted input/output routines:
   fprintf() and sscanf() */
#ifndef stdin
#define	stdin	0
#define	stdout	1
#define	stderr	2
#endif

/* converts "words per minute" and "characters per second" typing speeds
   to "milliseconds delay per character" for Typing_dly environment variable */
#define	WPM(A)	(10000/(A) + ((10000%(A)) >= (A)/2))
#define	CPS(A)	(1000/(A) + ((1000%(A)) >= (A)/2))

/* converts other time units to milliseconds for Timeout_val environment
   variable and delay() argument */
#define	HOURS(A)	((A) * 3600000)
#define	MINUTES(A)	((A) * 60000)
#define	SECONDS(A)	((A) * 1000)

/* defines all (non-X) environment variables for use in pop [...], reset [...],
   save [...], restore [...], and show [...] environment manipulation commands.
   The first definition omits the Line environment variable because of its
   special relationship to the other environment variables. */
#define ENV_VARS	Think_avg,Think_sd,Think_dist,Think_def,Typing_dly,Key_map,Parity,Baud,Charsize,Stopbits,Flow_control,Modem_control,Timeout_val,Timeout_act,Escape_seq,Logout_seq,Log_level,Record_level,Mystack,Mysstack,Mybstack,Emulation,Screen_mask,Screen_match,Think_max,Check_unread,Think_dly_scale,Typing_dly_scale,Delay_dly_scale,Timeout_scale,Suspend_check
#define EVERY_ENV_VAR	Think_avg,Think_sd,Think_dist,Think_def,Typing_dly,Key_map,Parity,Baud,Charsize,Stopbits,Flow_control,Modem_control,Timeout_val,Timeout_act,Escape_seq,Logout_seq,Log_level,Record_level,Mystack,Mysstack,Mybstack,Emulation,Screen_mask,Screen_match,Think_max,Check_unread,Think_dly_scale,Typing_dly_scale,Delay_dly_scale,Timeout_scale,Suspend_check,Line


/*
 *
 * VU SQL definitions
 *
 */


/*
 * ALL_ROWS is used in sqlnrecv commands to request all available
 * results
 */
#define ALL_ROWS	0


/*
 * LOOKUP_PWD is used in sqlconnect() to request that passwords be
 * obtained from the Authentication datapool
 */
#define LOOKUP_PWD	0x0BADF00D

/*
 * the following errors may be returned by some sql emulation commands
 * or functions.  They are not generated by the sql database server but
 * by VU playback.  All other errors returned by sql emulation commands
 * and functions are provided by the sql database server.
 */
#define PV_SQL_BASE		40000
#define PV_SQL_INTERNAL		(PV_SQL_BASE+ 0)  /* internal library error */
#define PV_SQL_LIBINIT		(PV_SQL_BASE+ 1)  /* lib initializaion */
#define PV_SQL_CONNECT		(PV_SQL_BASE+ 2)  /* failure to connect */
#define PV_SQL_TIMEOUT		(PV_SQL_BASE+ 3)  /* took too long */

#define PV_SQL_END_DATA		(PV_SQL_BASE+ 11) /* end of result set */
#define PV_SQL_END_RESULTS	(PV_SQL_BASE+ 12) /* end of all results */
#define PV_SQL_NOT_FETCHABLE	(PV_SQL_BASE+ 13) /* no results */

#define PV_SQL_UNIMPLEMENTED	(PV_SQL_BASE+ 21) /* unimplemented feature */
#define PV_SQL_MISMATCH		(PV_SQL_BASE+ 22) /* type mismatch */
#define PV_SQL_INVALID		(PV_SQL_BASE+ 23) /* invalid value */

#define PV_SQL_PREPID		(PV_SQL_BASE+ 31) /* unknown stmt id */
#define PV_SQL_PREPCON		(PV_SQL_BASE+ 32) /* other con's stmt id */
#define PV_SQL_PREPFAIL		(PV_SQL_BASE+ 33) /* failed prepare stmt id */

#define PV_SQL_CURSORID		(PV_SQL_BASE+ 41) /* unknown cursor id */
#define PV_SQL_CURSORCON	(PV_SQL_BASE+ 42) /* other con's cursor id */
#define PV_SQL_CURSORFAIL	(PV_SQL_BASE+ 43) /* failed declare cursor id */
#define PV_SQL_MULTIPLE_ERROR   (PV_SQL_BASE+ 44) /* multiple errors */



/* sqlsession options */

#define CURSESSID		1  /* used to set current session id on connection */
#define MIGRATABLE 		2  /* create session migratable */

/*
 * sqlsetoption(option, optarg, ...) option types listed by vendor
 */
/* 
 * dblib api options
*/
#define DBLIB_OPT_BASE	8000
#define DBLIB_CURSOR_TYPE		(DBLIB_OPT_BASE+ 1)  
#define DBLIB_CONCURRENCY		(DBLIB_OPT_BASE+ 2)  

/* dblib cursor types */
#define DBLIB_CURSOR_FORWARD	0
#define DBLIB_CURSOR_KEYSET_DRIVEN	1
#define DBLIB_CURSOR_DYNAMIC			2
#define DBLIB_CURSOR_STATIC 			3

/* odbc concurrency types */
#define DBLIB_CONCUR_READ_ONLY		1
#define DBLIB_CONCUR_LOCK			2
#define DBLIB_CONCUR_ROWVER			3
#define DBLIB_CONCUR_VALUES			4

/*
 * odbc options
 */
#define ODBC_OPT_BASE		7000
#define ODBC_CURSOR_TYPE	(ODBC_OPT_BASE+ 1) 	/* static, dynamic...*/
#define ODBC_CONCURRENCY	(ODBC_OPT_BASE+ 2)  
#define ODBC_GOTONEXTRESULTSET	(ODBC_OPT_BASE+ 3) /*  go to next result */ 
#define ODBC_AUTOCOMMIT	(ODBC_OPT_BASE+ 4)  /* 1=autocommit on 0=off. */
#define ODBC_MAX_ROWS	(ODBC_OPT_BASE+ 5)  /* the max # of rows to get */
#define ODBC_GET_VUcursorname	(ODBC_OPT_BASE+ 6)  /* store the cursorname in the read only variable _VUcursorname */
#define ODBC_MAX_DEF_COLSIZE	(ODBC_OPT_BASE+ 7)  /* max size to do a define for a column, set to -1 to turn off max size */

#define _VUcursorname _reference_URI 

/* odbc cursor types */
#define ODBC_CURSOR_FORWARD_ONLY	0
#define ODBC_CURSOR_KEYSET_DRIVEN	1
#define ODBC_CURSOR_DYNAMIC			2
#define ODBC_CURSOR_STATIC 			3

/* odbc concurrency types */
#define ODBC_CONCUR_READ_ONLY		1
#define ODBC_CONCUR_LOCK			2
#define ODBC_CONCUR_ROWVER			3
#define ODBC_CONCUR_VALUES			4

/*
 * oracle options
 */
#define ORA_OPT_BASE		6000
#define ORA_AUTOCOMMIT		(ORA_OPT_BASE+ 1)  /* 1 boolean argument */
#define ORA_DEFER		(ORA_OPT_BASE+ 2)  /* 1 boolean argument */
#define ORA_EXECCOUNT		(ORA_OPT_BASE+ 3)  /* a number for # of inserts */


/*
 * sybase options
 *
 * these options correspond to their obvious counterparts listed in the
 * Sybase include file 'cspublic.h'
 */
#define SYB_OPT_BASE		5000
#define SYB_OPT_DATEFIRST	(SYB_OPT_BASE+ 1) /* Set first day of week */
#define SYB_OPT_TEXTSIZE	(SYB_OPT_BASE+ 2) /* Text size */
#define SYB_OPT_STATS_TIME	(SYB_OPT_BASE+ 3) /* Server time statistics */
#define SYB_OPT_STATS_IO	(SYB_OPT_BASE+ 4) /* Server I/O statistics */
#define SYB_OPT_ROWCOUNT	(SYB_OPT_BASE+ 5) /* Maximum row count */
#define SYB_OPT_NATLANG		(SYB_OPT_BASE+ 6) /* National Language */
#define SYB_OPT_DATEFORMAT	(SYB_OPT_BASE+ 7) /* Date format */
#define SYB_OPT_ISOLATION	(SYB_OPT_BASE+ 8) /* Transaction isolation
						   * level */
#define SYB_OPT_AUTHON		(SYB_OPT_BASE+ 9) /* Set authority level on */
#define SYB_OPT_CHARSET		(SYB_OPT_BASE+10) /* Character set */
#define SYB_OPT_SHOWPLAN	(SYB_OPT_BASE+13) /* show execution plan */
 
#define SYB_OPT_NOEXEC		(SYB_OPT_BASE+14) /* don't execute query */
#define SYB_OPT_ARITHIGNORE	(SYB_OPT_BASE+15) /* ignore arithmetic
						   * exceptions */
#define SYB_OPT_TRUNCIGNORE	(SYB_OPT_BASE+16) /* support ANSI null values */
#define SYB_OPT_ARITHABORT	(SYB_OPT_BASE+17) /* abort on arithmetic
						   * exceptions */
#define SYB_OPT_PARSEONLY	(SYB_OPT_BASE+18) /* parse only, return error
						   * msgs */
#define SYB_OPT_GETDATA		(SYB_OPT_BASE+20) /* return trigger data */
#define SYB_OPT_NOCOUNT		(SYB_OPT_BASE+21) /* don't print done count */
#define SYB_OPT_FORCEPLAN	(SYB_OPT_BASE+23) /* force variable substitute
						   * order */
#define SYB_OPT_FORMATONLY	(SYB_OPT_BASE+24) /* send format w/o row */
#define SYB_OPT_CHAINXACTS	(SYB_OPT_BASE+25) /* chained transaction mode */
#define SYB_OPT_CURCLOSEONXACT	(SYB_OPT_BASE+26) /* close cursor on end trans*/
#define SYB_OPT_FIPSFLAG	(SYB_OPT_BASE+27) /* FIPS flag */
#define SYB_OPT_RESTREES	(SYB_OPT_BASE+28) /* return resolution trees */
#define SYB_OPT_IDENTITYON	(SYB_OPT_BASE+29) /* turn on explicit identity*/
#define SYB_OPT_CURREAD		(SYB_OPT_BASE+30) /* Set session label
						   * @@ curread */
#define SYB_OPT_CURWRITE	(SYB_OPT_BASE+31) /* Set session label 
						   * @@curwrite */
#define SYB_OPT_IDENTITYOFF	(SYB_OPT_BASE+32) /*turn off explicit identity*/
#define SYB_OPT_AUTHOFF		(SYB_OPT_BASE+33) /* Set authority level off */
#define SYB_OPT_ANSINULL	(SYB_OPT_BASE+34) /* ANSI NULLS behavior */
#define SYB_OPT_QUOTED_IDENT	(SYB_OPT_BASE+35) /* Quoted identifiers */
#define SYB_OPT_ANSIPERM	(SYB_OPT_BASE+36) /* ANSI permission checking */
#define SYB_OPT_STR_RTRUNC	(SYB_OPT_BASE+37) /* ANSI right truncation */
 
#define SYB_MIN_OPTION	SYB_OPT_DATEFIRST
#define SYB_MAX_OPTION	SYB_OPT_STR_RTRUNC

/*
 * The types and values for optarg are listed below for Sybase
 * options.  All Sybase options require exactly one optarg.
 * 
 * option			arg type	optarg
 * ---------------		---------	---------
 * SYB_OPT_DATEFIRST 		int		Defines below
 * SYB_OPT_TEXTSIZE 		int		Size in bytes 
 * SYB_OPT_ROWCOUNT  		int		Number of rows 
 * SYB_OPT_NATLANG 		string		National Lang
 * SYB_OPT_DATEFORMAT 		int		Defines below
 * SYB_OPT_ISOLATION 		int		Defines below		
 * SYB_OPT_AUTHON 		string		Table Name
 * SYB_OPT_CHARSET 		string		Character set
 * SYB_OPT_IDENTITYON 		string		Table Name
 * SYB_OPT_CURREAD 		string		Read Label
 * SYB_OPT_CURWRITE 		string		Write Label
 * SYB_OPT_IDENTITYOFF 		string		Table Name
 * SYB_OPT_AUTHOFF 		string		Table Name
 * (All remaining options)	int		Boolean value (non-zero true)
 */ 


/* SYB_OPT_DATEFIRST */
#define SYB_OPT_MONDAY		1
#define SYB_OPT_TUESDAY		2
#define SYB_OPT_WEDNESDAY	3
#define SYB_OPT_THURSDAY	4
#define SYB_OPT_FRIDAY		5
#define SYB_OPT_SATURDAY	6
#define SYB_OPT_SUNDAY		7

/* SYB_OPT_DATEFORMAT */
#define SYB_OPT_FMTMDY		1
#define SYB_OPT_FMTDMY		2
#define SYB_OPT_FMTYMD		3
#define SYB_OPT_FMTYDM		4
#define SYB_OPT_FMTMYD		5
#define SYB_OPT_FMTDYM		6

/* SYB_OPT_ISOLATION */
#define SYB_OPT_LEVEL1		1
#define SYB_OPT_LEVEL3		3

/* DB-Library options taken from sybdb.h */
#define DB_OPT_PARSEONLY     0
#define DB_OPT_ESTIMATE      1       
#define DB_OPT_SHOWPLAN      2
#define DB_OPT_NOEXEC        3
#define DB_OPT_ARITHIGNORE   4
#define DB_OPT_NOCOUNT       5
#define DB_OPT_ARITHABORT    6
#define DB_OPT_TEXTLIMIT     7
#define DB_OPT_BROWSE        8
#define DB_OPT_OFFSET        9
#define DB_OPT_STAT          10
#define DB_OPT_ERRLVL        11
#define DB_OPT_CONFIRM       12
#define DB_OPT_STORPROCID    13
#define DB_OPT_BUFFER        14
#define DB_OPT_NOAUTOFREE    15
#define DB_OPT_ROWCOUNT      16
#define DB_OPT_TEXTSIZE      17
#define DB_OPT_NATLANG       18
#define DB_OPT_DATEFORMAT    19
#define DB_OPT_PRPAD         20
#define DB_OPT_PRCOLSEP      21
#define DB_OPT_PRLINELEN     22
#define DB_OPT_PRLINESEP     23
#define DB_OPT_LFCONVERT     24
#define DB_OPT_DATEFIRST     25
#define DB_OPT_CHAINXACTS    26
#define DB_OPT_FIPSFLAG	     27
#define DB_OPT_ISOLATION     28
#define DB_OPT_AUTH	     29
#define DB_OPT_IDENTITY	     30
#define DB_OPT_NOIDCOL       31


/*
 * flags to indicate acceptible values for http_header_recv.  These are
 * set in Http_control.  Multiple values may be OR'ed together.
 */

#define HTTP_PARTIAL_OK		0x1   /* accept 206 for 200 */
#define HTTP_CACHE_OK		0x2   /* accept 304 for 200 */
#define HTTP_PERM_REDIRECT_OK	0x4   /* accept 301 for 200 */
#define HTTP_TEMP_REDIRECT_OK	0x8   /* accept 302 for 200 */
#define HTTP_REDIRECT_OK	(HTTP_PERM_REDIRECT_OK | HTTP_TEMP_REDIRECT_OK)


/*   
 * HTTP connection symbolic constants used in http_request emulation command.
 * A connection attribute can be a combination of some of these flags.
 */

#define HTTP_CONN_SECURE 	 0x0001 /* secure connection Strength Unknown */
#define HTTP_CONN_SECURE_40 	 0x0101 /* secure connection 40 bit */
#define HTTP_CONN_SECURE_56 	 0x0201 /* secure connection 56 bit */
#define HTTP_CONN_SECURE_128 	 0x0401 /* secure connection 128 bit */
#define HTTP_CONN_SECURE_168 	 0x0801 /* secure connection 168 bit */
#define HTTP_CONN_DIRECT 	 0x0002 /* direct conn without any proxies */
#define HTTP_CONN_PROXY  	 0x0004 /* connection involved proxy */
#define HTTP_CONN_GATEWAY 	 0x0008 /* connection involved a gateway */
#define HTTP_CONN_TUNNEL  	 0x0010 /* connection is tunnel (transparent) */
#define HTTP_CONN_NO_SSL2 	 0x4000 /* SSL ver 2 connections not allowed */
#define HTTP_CONN_NO_SSL3 	 0x8000 /* SSL ver 3 connections not allowed */


/*
 * HTTP search types for http_find_values()
 */

#define HTTP_FORM_DATA          0x0001 
#define HTTP_HREF_DATA          0x0002
#define HTTP_COOKIE_DATA        0x0004
#define HTTP_LOCATION_DATA      0x0008
#define HTTP_REDIRECT_PREFIX    0x0100


/*
 * supported types for sock_create
 */
#define SOCK_TYPE_STREAM	1

/* Check http_find_values() result */
#ifndef ABORT_IF_FIND_VALUES_FAILS

#define CHECK_FIND_RESULT(VAR,ITEM,VALUE) \
if (limitof VAR < 0) { VAR[0] = VALUE; fprintf(stderr, "*** http_find_values() could not find the value for \"%s\" at Line %d ***\n", ITEM, _lineno);}

#else

#define CHECK_FIND_RESULT(VAR,ITEM,VALUE)


#endif /* ABORT_IF_FIND_VALUES_FAILS */

#endif /* __VU_H__ */

